@@ -82,3 +82,18 @@ def startswith(prefix, S, *, start = None, end = None):
     else:   
         return S.startswith(prefix)
 
+
+@pipeable
+def join(sep, seq):
+    ''' Concatenate any number of strings.
+    
+    The string whose method is called is inserted in between each given string.
+    The result is returned as a new string.
+    
+    Example: 
+
+    >>> from composable.string import join
+    >>> ['ab', 'pq', 'rs'] >> join('.')
+    'ab.pq.rs'
+    '''
+    return sep.join(seq)
